izug.ticketbox
==============

This Package provides a basic Tracker like Content-Type


Usage
-----

- Add ``izug.ticketbox`` and your the implementation package to your
  buildout configuration:

::

    [instance]
    eggs +=
        izug.ticketbox

- Use ``izug.ticketbox [zip_export]`` if you want to enable zip export.

- Install the generic setup profiles of those packages.

- Edit any content: on the bottom of the form there is new checkbox "Send
  notification".


Links
-----

- Github: https://github.com/4teamwork/izug.ticketbox
- Issues: https://github.com/4teamwork/izug.ticketbox/issues
- Pypi: http://pypi.python.org/pypi/izug.ticketbox
- Continuous integration: https://jenkins.4teamwork.ch/search?q=izug.ticketbox


Copyright
---------

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``izug.ticketbox`` is licensed under GNU General Public License, version 2.


